# Produce a build suitable for release, i.e. use PGO/LTO. You can turn it off
# when building locally to reduce build time.
%global release_build     1

# Excluded due to https://bugzilla.mozilla.org/show_bug.cgi?id=1792159
# https://bugzilla.redhat.com/show_bug.cgi?id=2129720
ExcludeArch: i686

# Run Mozilla test suite as a part of compile rpm section. Turn off when
# building locally and don't want to spend 24 hours waiting for results.
%global run_firefox_tests 0
%ifarch x86_64 %{ix86}
%global run_firefox_tests 0
%endif

# Don't create debuginfo rpm packages. It reduces build time as
# exctracting debuginfo takes long time.
%global create_debuginfo  1

# Produce debug (non-optimized) package build. Suitable for debugging only
# as the build is *very* slow.
%global debug_build       0

# See rhbz#2134527 - Use portal Gtk file dialog
# Disabled due to various issues now.
%global use_xdg_file_portal 0

%global system_nss        1
%global system_libevent   1
%global build_with_asan   0
%ifarch x86_64 %{ix86}
%global enable_replace_malloc 1
%else
%global enable_replace_malloc 0
%endif

# wasi_sdk is for sandboxing third party c/c++ libs by using rlbox, exclude s390x on the f39.
%if 0%{?fedora} < 40
%ifarch s390x
%bcond wasi_sdk 0
%else
%bcond wasi_sdk 1
%endif
%else
%bcond wasi_sdk 1
%endif

%if "%{toolchain}" == "clang"
%global build_with_clang 1
%else
%global build_with_clang 0
%endif

%global gnome_shell_search_provider 0
%if 0%{?fedora} >= 40
%global gnome_shell_search_provider 1
%endif

# Temporary disabled due to
# https://bugzilla.redhat.com/show_bug.cgi?id=1951606
%global enable_mozilla_crashreporter 0
%ifarch x86_64 %{ix86}
%global enable_mozilla_crashreporter 1
%endif
%if %{build_with_asan}
%global enable_mozilla_crashreporter 0
%endif
%if 0%{?flatpak}
%global enable_mozilla_crashreporter 0
%endif
%if !%{create_debuginfo}
%define _unpackaged_files_terminate_build 0
%global debug_package %{nil}
%global enable_mozilla_crashreporter 0
%endif

%global system_ffi        1
%global system_av1        0
%global system_libvpx     1
%global system_jpeg       1
%global system_pixman     1
%global system_webp       1
# Bundled cbindgen makes build slow.
# Enable only if system cbindgen is not available.
%if 0%{?rhel}
%global use_bundled_cbindgen  1
%else
%global use_bundled_cbindgen  1
%endif
%if %{debug_build}
%global release_build     0
%endif
# Build PGO+LTO on x86_64 only due to build issues
# on other arches.
%global build_with_pgo    0
%ifarch x86_64
%if %{release_build}
%global build_with_pgo    1
%endif
%endif
%if 0%{?flatpak}
%global build_with_pgo    0
%endif
# Big endian platforms
%ifarch s390x
%global big_endian        1
%endif

%if 0%{?build_with_pgo}
%global use_xvfb          1
%global build_tests       1
%endif

%if 0%{?run_firefox_tests}
%global use_xvfb          1
%global build_tests       1
%endif

%global launch_wayland_compositor 0
%if %{build_with_pgo}
%global launch_wayland_compositor 1
%endif
%if %{run_firefox_tests}
%global launch_wayland_compositor 1
%endif

%global default_bookmarks_file  %{_datadir}/bookmarks/default-bookmarks.html
%global firefox_app_id  \{ec8030f7-c20a-464f-9b0e-13a3a9e97384\}
# Minimal required versions
%global cairo_version 1.13.1
%global freetype_version 2.1.9
%global libnotify_version 0.7.0
%if %{?system_av1}
%global aom_version 1.0.0
%global dav1d_version 1.0.0
%endif
%if %{?system_libvpx}
%global libvpx_version 1.10.0
%endif
%if %{?system_webp}
%global libwebp_version 1.1.0
%endif

%if %{?system_nss}
%global nspr_version 4.32
%global nspr_build_version %{nspr_version}
%global nss_version 3.97
%global nss_build_version %{nss_version}
%endif

%global mozappdir     %{_libdir}/firefox
%global mozappdirdev  %{_libdir}/firefox-devel-%{version}
%global langpackdir   %{mozappdir}/langpacks
%global tarballdir    firefox-%{version}

%global official_branding       1

%bcond_without langpacks

%if %{with langpacks}
%bcond_without langpacks_subpkg
%endif

%if !%{release_build}
%global pre_tag .npgo
%endif
%if %{build_with_clang}
%global pre_tag .clang
%endif
%if %{build_with_asan}
%global pre_tag .asan
%global build_with_pgo    0
%endif
%if !%{system_nss}
%global nss_tag .nss
%endif
%if %{debug_build}
%global pre_tag .debug
%endif

# Exclude private libraries from autogenerated provides and requires
%global __provides_exclude_from ^%{mozappdir}
%global __requires_exclude ^(%%(find %{buildroot}%{mozappdir} -name '*.so' | xargs -n1 basename | sort -u | paste -s -d '|' -))

%undefine _package_note_flags
# for https://bugzilla.redhat.com/show_bug.cgi?id=2184553
%global _package_note_status 0

Summary:        Mozilla Firefox Web browser
Name:           firefox
Version:        125.0
Release:        1%{?pre_tag}%{?dist}
URL:            https://www.mozilla.org/firefox/
License:        MPLv1.1 or GPLv2+ or LGPLv2+
Source0:        https://archive.mozilla.org/pub/firefox/releases/%{version}%{?pre_version}/source/firefox-%{version}%{?pre_version}.source.tar.xz
%if %{with langpacks}
Source1:        firefox-langpacks-%{version}%{?pre_version}-20240409.tar.xz
%endif
Source2:        cbindgen-vendor.tar.xz
Source3:        dump_syms-vendor.tar.xz
Source10:       firefox-mozconfig
Source12:       firefox-redhat-default-prefs.js
Source20:       firefox.desktop
Source21:       firefox.sh.in
Source23:       firefox.1
Source24:       mozilla-api-key
Source25:       firefox-symbolic.svg
Source26:       distribution.ini
Source27:       google-api-key
Source28:       firefox-wayland.sh.in
Source29:       firefox-wayland.desktop
Source30:       firefox-x11.sh.in
Source31:       firefox-x11.desktop
Source32:       node-stdout-nonblocking-wrapper
Source33:       firefox.appdata.xml.in
Source34:       org.mozilla.firefox.search-provider.ini
Source35:       google-loc-api-key
Source37:       mochitest-python.tar.gz
Source38:       print_results
Source39:       print-errors
Source40:       run-tests-x11
Source41:       run-tests-wayland
Source42:       psummary
Source43:       print_failures
Source44:       print-error-reftest
Source45:       run-wayland-compositor
Source46:       org.mozilla.firefox.SearchProvider.service
Source47:       org.mozilla.firefox.desktop
Source48:       org.mozilla.firefox.appdata.xml.in
Source49:       wasi.patch.template
# Created by:
# git clone --recursive https://github.com/WebAssembly/wasi-sdk.git
# cd wasi-sdk && git-archive-all --force-submodules wasi-sdk-20.tar.gz
Source50:       wasi-sdk-20.tar.gz

# Build patches
#Patch3:         mozilla-build-arm.patch
Patch32:        build-rust-ppc64le.patch
Patch35:        build-ppc-jit.patch
# Fixing missing cacheFlush when JS_CODEGEN_NONE is used (s390x)
Patch38:        build-cacheFlush-missing.patch
Patch40:        build-aarch64-skia.patch
Patch44:        build-arm-libopus.patch
Patch46:        firefox-nss-version.patch
Patch47:        fedora-shebang-build.patch
Patch53:        firefox-gcc-build.patch
Patch54:        mozilla-1669639.patch
Patch55:        firefox-testing.patch
Patch61:        firefox-glibc-dynstack.patch
Patch71:        0001-GLIBCXX-fix-for-GCC-12.patch
Patch78:        firefox-i686-build.patch
Patch79:        firefox-gcc-13-build.patch
Patch80:        wasi.patch

# Test patches
# Generate without context by
# GENDIFF_DIFF_ARGS=-U0 gendiff firefox-xxxx .firefox-tests-xpcshell
# GENDIFF_DIFF_ARGS=-U0 gendiff firefox-xxxx .firefox-tests-reftest
Patch100:       firefox-tests-xpcshell.patch
Patch101:       firefox-tests-reftest.patch
Patch102:       firefox-tests-xpcshell-freeze.patch

# Fedora specific patches
Patch215:        firefox-enable-addons.patch
Patch219:        rhbz-1173156.patch
#ARM run-time patch
Patch226:        rhbz-1354671.patch
Patch228:        disable-openh264-download.patch
Patch229:        firefox-nss-addon-hack.patch
Patch230:        firefox-enable-vaapi.patch
Patch231:        fedora-customization.patch
Patch241:        0025-Add-KDE-integration-to-Firefox-toolkit-parts.patch
Patch242:        0026-Add-KDE-integration-to-Firefox.patch

# Upstream patches
Patch402:        mozilla-1196777.patch
Patch407:        mozilla-1667096.patch

# PGO/LTO patches
Patch600:        pgo.patch
Patch602:        mozilla-1516803.patch
Patch603:        firefox-gcc-always-inline.patch

# system AV1 patches (from Gentoo)
Patch800:        bmo-1559213-Support-system-av1.patch
Patch801:        bmo-1559213-fix-system-av1-libs.patch

# tentative patch for RUSTFLAGS parsing issue:
# https://bugzilla.redhat.com/show_bug.cgi?id=2184743
# https://bugzilla.mozilla.org/show_bug.cgi?id=1474486
# not upstreaming till I'm more sure it's correct
Patch1200:       firefox-112.0-commasplit.patch

%if %{?system_nss}
BuildRequires:  pkgconfig(nspr) >= %{nspr_version}
BuildRequires:  pkgconfig(nss) >= %{nss_version}
BuildRequires:  nss-static >= %{nss_version}
%endif
BuildRequires:  pkgconfig(libpng)
%if %{?system_jpeg}
BuildRequires:  libjpeg-devel
%endif
%if %{?system_pixman}
BuildRequires:  pixman-devel
%endif
BuildRequires:  zip
BuildRequires:  bzip2-devel
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(krb5)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(freetype2) >= %{freetype_version}
BuildRequires:  pkgconfig(xt)
BuildRequires:  pkgconfig(xrender)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(libnotify) >= %{libnotify_version}
BuildRequires:  pkgconfig(dri)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  dbus-glib-devel
%if %{?system_av1}
BuildRequires:  pkgconfig(aom) >= %{aom_version}
BuildRequires:  pkgconfig(dav1d) >= %{dav1d_version}
%endif
%if %{?system_libvpx}
BuildRequires:  libvpx-devel >= %{libvpx_version}
%endif
%if %{?system_webp}
BuildRequires:  pkgconfig(libwebp) >= %{libwebp_version}
BuildRequires:  pkgconfig(libwebpdemux) >= %{libwebp_version}
%endif
BuildRequires:  autoconf213
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  yasm
BuildRequires:  llvm
BuildRequires:  llvm-devel
BuildRequires:  clang
BuildRequires:  clang-libs
%if %{build_with_clang} || %{with wasi_sdk}
BuildRequires:  lld
%endif

BuildRequires:  pipewire-devel

%if !0%{?use_bundled_cbindgen}
BuildRequires:  cbindgen
%endif
BuildRequires:  nodejs
BuildRequires:  nasm >= 1.13
BuildRequires:  libappstream-glib

%if 0%{?big_endian}
BuildRequires:  icu
%endif

Requires:       mozilla-filesystem
Recommends:     mozilla-openh264 >= 2.1.1
%if %{with langpacks_subpkg}
Recommends:     firefox-langpacks = %{version}-%{release}
%else
Obsoletes:      firefox-langpacks < %{version}-%{release}
%endif
Recommends:     libva
Requires:       p11-kit-trust
Requires:       pciutils-libs
%if %{?system_nss}
Requires:       nspr >= %{nspr_build_version}
Requires:       nss >= %{nss_build_version}
%endif
%if %{?system_libevent}
BuildRequires:  pkgconfig(libevent)
%endif
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3.11-devel
%if !0%{?flatpak}
Requires:       u2f-hidraw-policy
%endif
%if %{?use_xdg_file_portal}
Requires:       xdg-desktop-portal
%endif

BuildRequires:  desktop-file-utils
%if !0%{?flatpak}
BuildRequires:  system-bookmarks
%endif
%if %{?system_ffi}
BuildRequires:  pkgconfig(libffi)
%endif

%if 0%{?use_xvfb}
BuildRequires:  xorg-x11-server-Xvfb
%endif
BuildRequires:  rust
BuildRequires:  cargo
BuildRequires:  clang-devel
%if %{build_with_asan}
BuildRequires:  libasan
BuildRequires:  libasan-static
%endif
BuildRequires:  perl-interpreter
BuildRequires:  fdk-aac-free-devel
%if 0%{?launch_wayland_compositor}
BuildRequires:  mutter
BuildRequires:  gsettings-desktop-schemas
BuildRequires:  gnome-settings-daemon
BuildRequires:  mesa-dri-drivers
BuildRequires:  xorg-x11-server-Xwayland
BuildRequires:  dbus-x11
BuildRequires:  gnome-keyring
%endif
%if 0%{?run_firefox_tests}
BuildRequires:  procps-ng
BuildRequires:  nss-tools
BuildRequires:  python2.7
BuildRequires:  dejavu-sans-mono-fonts
BuildRequires:  dejavu-sans-fonts
BuildRequires:  dejavu-serif-fonts
BuildRequires:  dbus-x11
BuildRequires:  gnome-keyring
BuildRequires:  mesa-dri-drivers
# ----------------------------------------
BuildRequires:  liberation-fonts-common
BuildRequires:  liberation-mono-fonts
BuildRequires:  liberation-sans-fonts
BuildRequires:  liberation-serif-fonts
# ----------------------------------
BuildRequires:  google-carlito-fonts
BuildRequires:  google-droid-sans-fonts
BuildRequires:  google-noto-fonts-common
BuildRequires:  google-noto-cjk-fonts-common
BuildRequires:  google-noto-sans-cjk-ttc-fonts
BuildRequires:  google-noto-sans-gurmukhi-fonts
BuildRequires:  google-noto-sans-fonts
BuildRequires:  google-noto-emoji-color-fonts
BuildRequires:  google-noto-sans-sinhala-vf-fonts
# -----------------------------------
BuildRequires:  thai-scalable-fonts-common
BuildRequires:  thai-scalable-waree-fonts
BuildRequires:  khmeros-base-fonts
BuildRequires:  jomolhari-fonts
# ----------------------------------
BuildRequires:  lohit-tamil-fonts
BuildRequires:  lohit-telugu-fonts
# ----------------------------------
BuildRequires:  paktype-naskh-basic-fonts
BuildRequires:  pt-sans-fonts
BuildRequires:  smc-meera-fonts
BuildRequires:  stix-fonts
BuildRequires:  abattis-cantarell-fonts
BuildRequires:  xorg-x11-fonts-ISO8859-1-100dpi
BuildRequires:  xorg-x11-fonts-misc
%endif
BuildRequires:  make
BuildRequires:  pciutils-libs
BuildRequires:  mesa-libgbm-devel
BuildRequires:  libproxy-devel
# Required for --enable-replace-malloc
%if %{enable_replace_malloc}
BuildRequires:  libstdc++-static
%endif
%if %{with wasi_sdk}
BuildRequires:  clang cmake ninja-build
%endif

Obsoletes:      mozilla <= 37:1.7.13
Provides:       webclient

# Don't ship firefox-x11 and firefox-wayland on Fedora 40.
# Wayland backend is considered as mature enough now.
%if 0%{?fedora} >= 40
Obsoletes:  firefox-wayland < 122.0-2
Obsoletes:  firefox-x11 < 122.0-2
%endif

%description
Mozilla Firefox is an open-source web browser, designed for standards
compliance, performance and portability.

%if %{with langpacks_subpkg}
%package langpacks
Summary: Firefox langpacks
Requires: %{name} = %{version}-%{release}
%description langpacks
The firefox-langpacks package contains all the localization
and translations langpack add-ons.
%files langpacks -f %{name}.lang
%dir %{langpackdir}
%endif

%if %{enable_mozilla_crashreporter}
%global moz_debug_prefix %{_prefix}/lib/debug
%global moz_debug_dir %{moz_debug_prefix}%{mozappdir}
%global uname_m %(uname -m)
%global symbols_file_name %{name}-%{version}.en-US.%{_os}-%{uname_m}.crashreporter-symbols.zip
%global symbols_file_path %{moz_debug_dir}/%{symbols_file_name}
%global _find_debuginfo_opts %{limit_build -m 32768} -p %{symbols_file_path} -o debugcrashreporter.list
%global crashreporter_pkg_name mozilla-crashreporter-%{name}-debuginfo
%package -n %{crashreporter_pkg_name}
Summary: Debugging symbols used by Mozilla's crash reporter servers
%description -n %{crashreporter_pkg_name}
This package provides debug information for Firefox, for use by
Mozilla's crash reporter servers.  If you are trying to locally
debug %{name}, you want to install %{name}-debuginfo instead.
%files -n %{crashreporter_pkg_name} -f debugcrashreporter.list
%else
%global _find_debuginfo_opts %{limit_build -m 32768}
%endif

%if 0%{?fedora} < 40
%package x11
Summary: Firefox X11 launcher.
Requires: %{name}
%description x11
The firefox-x11 package contains launcher and desktop file
to run Firefox explicitly on X11.
%files x11
%{_bindir}/firefox-x11
%{_datadir}/applications/firefox-x11.desktop

%package wayland
Summary: Firefox Wayland launcher.
Requires: %{name}
%description wayland
The firefox-wayland package contains launcher and desktop file
to run Firefox explicitly on Wayland.
%files wayland
%{_bindir}/firefox-wayland
%{_datadir}/applications/firefox-wayland.desktop
%endif

%if 0%{?run_firefox_tests}
%global testsuite_pkg_name %{name}-testresults
%package -n %{testsuite_pkg_name}
Summary: Results of testsuite
%description -n %{testsuite_pkg_name}
This package contains results of tests executed during build.
%files -n %{testsuite_pkg_name}
/%{version}-%{release}/test_results
/%{version}-%{release}/test_summary.txt
/%{version}-%{release}/failures-*
%endif

#---------------------------------------------------------------------

%prep
%setup -q -n %{tarballdir}
%if %{with wasi_sdk}
%setup -q -T -D -a 50
%endif

# Build patches, can't change backup suffix from default because during build
# there is a compare of config and js/config directories and .orig suffix is
# ignored during this compare.

%patch40 -p1 -b .aarch64-skia
%patch44 -p1 -b .build-arm-libopus
%patch47 -p1 -b .fedora-shebang
%patch53 -p1 -b .firefox-gcc-build
%patch54 -p1 -b .1669639
%patch71 -p1 -b .0001-GLIBCXX-fix-for-GCC-12
%patch78 -p1 -b .firefox-i686
%patch79 -p1 -b .firefox-gcc-13-build

# We need to create the wasi.patch with the correct path to the wasm libclang_rt.
%if %{with wasi_sdk}
export LIBCLANG_RT=`pwd`/wasi-sdk-20/build/compiler-rt/lib/wasi/libclang_rt.builtins-wasm32.a; cat %{SOURCE49} | envsubst > %{_sourcedir}/wasi.patch
%patch80 -p1 -b .wasi
%endif

# Test patches
#%patch100 -p1 -b .firefox-tests-xpcshell
#%patch101 -p1 -b .firefox-tests-reftest
#%patch102 -p1 -b .firefox-tests-xpcshell-freeze

# Fedora patches
%patch215 -p1 -b .addons
%patch219 -p1 -b .rhbz-1173156
#ARM run-time patch
%ifarch aarch64
%patch226 -p1 -b .1354671
%endif
%patch228 -p1 -b .disable-openh264-download
%patch229 -p1 -b .firefox-nss-addon-hack
%patch230 -p1 -b .firefox-enable-vaapi
%patch231 -p1 -b .fedora-customization
#%patch241 -p1 -b .kde-integration-toolkit
#%patch242 -p1 -b .kde-integration

%patch402 -p1 -b .1196777
%patch407 -p1 -b .1667096

# PGO patches
%if %{build_with_pgo}
%if !%{build_with_clang}
%patch600 -p1 -b .pgo
%patch602 -p1 -b .1516803
%endif
%endif
%patch603 -p1 -b .inline

#%patch800 -p1 -b .system-av1
#%patch801 -p1 -b .system-av1-fixup

%patch1200 -p1 -b .rustflags-commasplit

rm -f .mozconfig
cp %{SOURCE10} .mozconfig
echo "ac_add_options --enable-default-toolkit=cairo-gtk3-wayland" >> .mozconfig
%if %{official_branding}
echo "ac_add_options --enable-official-branding" >> .mozconfig
%endif
cp %{SOURCE24} mozilla-api-key
cp %{SOURCE27} google-api-key
cp %{SOURCE35} google-loc-api-key

echo "ac_add_options --prefix=\"%{_prefix}\"" >> .mozconfig
echo "ac_add_options --libdir=\"%{_libdir}\"" >> .mozconfig

%if %{?system_nss}
echo "ac_add_options --with-system-nspr" >> .mozconfig
echo "ac_add_options --with-system-nss" >> .mozconfig
%else
echo "ac_add_options --without-system-nspr" >> .mozconfig
echo "ac_add_options --without-system-nss" >> .mozconfig
%endif

%if %{?system_libevent}
echo "ac_add_options --with-system-libevent" >> .mozconfig
%endif

%if %{?system_ffi}
echo "ac_add_options --enable-system-ffi" >> .mozconfig
%endif

%ifarch aarch64
echo "ac_add_options --disable-elf-hack" >> .mozconfig
%endif
%ifarch ppc64le
echo "ac_add_options --disable-webrtc" >> .mozconfig
%endif

%if %{?debug_build}
echo "ac_add_options --enable-debug" >> .mozconfig
echo "ac_add_options --disable-optimize" >> .mozconfig
%else
%global optimize_flags "none"
%ifarch ppc64le aarch64
%global optimize_flags "-g -O2"
%endif
%if %{optimize_flags} != "none"
echo 'ac_add_options --enable-optimize=%{?optimize_flags}' >> .mozconfig
%else
echo 'ac_add_options --enable-optimize' >> .mozconfig
%endif
echo "ac_add_options --disable-debug" >> .mozconfig
%endif

# Second arches fail to start with jemalloc enabled
%ifnarch %{ix86} x86_64
echo "ac_add_options --disable-jemalloc" >> .mozconfig
%endif

%if !%{enable_mozilla_crashreporter}
echo "ac_add_options --disable-crashreporter" >> .mozconfig
%endif

%if 0%{?build_tests}
echo "ac_add_options --enable-tests" >> .mozconfig
%else
echo "ac_add_options --disable-tests" >> .mozconfig
%endif

%if !%{?system_jpeg}
echo "ac_add_options --without-system-jpeg" >> .mozconfig
%else
echo "ac_add_options --with-system-jpeg" >> .mozconfig
%endif

%if %{?system_pixman}
echo "ac_add_options --enable-system-pixman" >> .mozconfig
%endif

%if %{?system_av1}
#echo "ac_add_options --with-system-av1" >> .mozconfig
%else
#echo "ac_add_options --without-system-av1" >> .mozconfig
%endif

%if %{?system_libvpx}
echo "ac_add_options --with-system-libvpx" >> .mozconfig
%else
echo "ac_add_options --without-system-libvpx" >> .mozconfig
%endif

%if %{?system_webp}
echo "ac_add_options --with-system-webp" >> .mozconfig
%else
echo "ac_add_options --without-system-webp" >> .mozconfig
%endif

%ifarch s390x
echo "ac_add_options --disable-jit" >> .mozconfig
%endif

%if %{build_with_asan}
echo "ac_add_options --enable-address-sanitizer" >> .mozconfig
echo "ac_add_options --disable-jemalloc" >> .mozconfig
%endif

# api keys full path
echo "ac_add_options --with-mozilla-api-keyfile=`pwd`/mozilla-api-key" >> .mozconfig
# It seems that the api key we have is for the safe browsing only
echo "ac_add_options --with-google-location-service-api-keyfile=`pwd`/google-loc-api-key" >> .mozconfig
echo "ac_add_options --with-google-safebrowsing-api-keyfile=`pwd`/google-api-key" >> .mozconfig

# https://bugzilla.redhat.com/show_bug.cgi?id=2239046
# with clang 17 upstream's detection fails, so let's just tell it
# where to look
echo "ac_add_options --with-libclang-path=`llvm-config --libdir`" >> .mozconfig

%if %{enable_replace_malloc}
echo "ac_add_options --enable-replace-malloc" >> .mozconfig
%endif

echo 'export NODEJS="%{_buildrootdir}/bin/node-stdout-nonblocking-wrapper"' >> .mozconfig

# Remove executable bit to make brp-mangle-shebangs happy.
chmod -x third_party/rust/itertools/src/lib.rs
chmod a-x third_party/rust/ash/src/extensions/ext/*.rs
chmod a-x third_party/rust/ash/src/extensions/khr/*.rs
chmod a-x third_party/rust/ash/src/extensions/nv/*.rs

#---------------------------------------------------------------------

%build
# Disable LTO to work around rhbz#1883904
# Is that already fixed?
%define _lto_cflags %{nil}

#WASI SDK
%if %{with wasi_sdk}
pushd wasi-sdk-20
NINJA_FLAGS=-v CC=clang CXX=clang++ env -u CFLAGS -u CXXFLAGS -u FFLAGS -u VALFLAGS -u RUSTFLAGS -u LDFLAGS -u LT_SYS_LIBRARY_PATH make package
popd
%endif 
# ^ with wasi_sdk

%if 0%{?use_bundled_cbindgen}
mkdir -p my_rust_vendor
cd my_rust_vendor
tar xf %{SOURCE2}
mkdir -p .cargo
cat > .cargo/config <<EOL
[source.crates-io]
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "`pwd`"
EOL

env CARGO_HOME=.cargo cargo install cbindgen
export PATH=`pwd`/.cargo/bin:$PATH
cd -
%else
export CBINDGEN=/usr/bin/cbindgen
%endif

%if %{enable_mozilla_crashreporter}
mkdir -p my_rust_vendor_dump_syms
cd my_rust_vendor_dump_syms
tar xf %{SOURCE3}
mkdir -p .cargo
cat > .cargo/config <<EOL
[source.crates-io]
replace-with = "vendored-sources"

[source.vendored-sources]
directory = "`pwd`"
EOL

env CARGO_HOME=.cargo cargo install dump_syms
export PATH=`pwd`/.cargo/bin:$PATH
cd -
%endif

mkdir %{_buildrootdir}/bin || :
cp %{SOURCE32} %{_buildrootdir}/bin || :

# Update the various config.guess to upstream release for aarch64 support
# Do not update config.guess in the ./third_party/rust because that would break checksums
find ./ -path ./third_party/rust -prune -o -name config.guess -exec cp /usr/lib/rpm/config.guess {} ';'

MOZ_OPT_FLAGS=$(echo "%{optflags}" | sed -e 's/-Wall//')
#rhbz#1037063
# -Werror=format-security causes build failures when -Wno-format is explicitly given
# for some sources
# Explicitly force the hardening flags for Firefox so it passes the checksec test;
# See also https://fedoraproject.org/wiki/Changes/Harden_All_Packages
# Workaround for mozbz#1531309
MOZ_OPT_FLAGS=$(echo "$MOZ_OPT_FLAGS" | sed -e 's/-Werror=format-security//')
# More Fedora specific build flags
MOZ_OPT_FLAGS="$MOZ_OPT_FLAGS -fpermissive"
%if %{?debug_build}
MOZ_OPT_FLAGS=$(echo "$MOZ_OPT_FLAGS" | sed -e 's/-O2//')
%endif
# If MOZ_DEBUG_FLAGS is empty, firefox's build will default it to "-g" which
# overrides the -g1 from line above and breaks building on s390/arm
# (OOM when linking, rhbz#1238225)
%ifarch %{ix86}
MOZ_OPT_FLAGS=$(echo "$MOZ_OPT_FLAGS" | sed -e 's/-g/-g0/')
%else
# this reduces backtrace quality substantially, but seems to be needed
# to prevent various OOM conditions during build
# https://bugzilla.redhat.com/show_bug.cgi?id=2241690
MOZ_OPT_FLAGS=$(echo "$MOZ_OPT_FLAGS" | sed -e 's/-g/-g1/')
%endif
export MOZ_DEBUG_FLAGS=" "
MOZ_LINK_FLAGS="%{build_ldflags}"
%if !%{build_with_clang}
%ifarch aarch64 %{ix86}
MOZ_LINK_FLAGS="$MOZ_LINK_FLAGS -Wl,--no-keep-memory -Wl,--reduce-memory-overheads"
%endif
%endif
%ifarch %{ix86} s390x
export RUSTFLAGS="-Cdebuginfo=0"
%endif
%if %{build_with_asan}
MOZ_OPT_FLAGS="$MOZ_OPT_FLAGS -fsanitize=address -Dxmalloc=myxmalloc"
MOZ_LINK_FLAGS="$MOZ_LINK_FLAGS -fsanitize=address -ldl"
%endif

# We don't wantfirefox to use CK_GCM_PARAMS_V3 in nss
MOZ_OPT_FLAGS="$MOZ_OPT_FLAGS -DNSS_PKCS11_3_0_STRICT"

echo "export CFLAGS=\"$MOZ_OPT_FLAGS\"" >> .mozconfig
echo "export CXXFLAGS=\"$MOZ_OPT_FLAGS\"" >> .mozconfig
echo "export LDFLAGS=\"$MOZ_LINK_FLAGS\"" >> .mozconfig

%if %{build_with_clang}
echo "export LLVM_PROFDATA=\"llvm-profdata\"" >> .mozconfig
echo "export AR=\"llvm-ar\"" >> .mozconfig
echo "export NM=\"llvm-nm\"" >> .mozconfig
echo "export RANLIB=\"llvm-ranlib\"" >> .mozconfig
echo "ac_add_options --enable-linker=lld" >> .mozconfig
%else
echo "export CC=gcc" >> .mozconfig
echo "export CXX=g++" >> .mozconfig
echo "export AR=\"gcc-ar\"" >> .mozconfig
echo "export NM=\"gcc-nm\"" >> .mozconfig
echo "export RANLIB=\"gcc-ranlib\"" >> .mozconfig
%endif
%if 0%{?build_with_pgo}
# PGO build doesn't work with ccache
export CCACHE_DISABLE=1
export GCOV_PREFIX=`pwd -P`/objdir
export GCOV_PREFIX_STRIP=$(( $(echo `pwd -P`|tr -c -d '/' |wc -c )+2 ))
env | grep GCOV
echo "ac_add_options --enable-lto" >> .mozconfig
echo "ac_add_options MOZ_PGO=1" >> .mozconfig
%endif
 
%if %{with wasi_sdk}
echo "ac_add_options --with-wasi-sysroot=`pwd`/wasi-sdk-20/build/install/opt/wasi-sdk/share/wasi-sysroot" >> .mozconfig
%else
echo "ac_add_options --without-sysroot" >> .mozconfig
echo "ac_add_options --without-wasm-sandboxed-libraries" >> .mozconfig
%endif

# Require 4 GB of RAM per CPU core
%constrain_build -m 4096
echo "mk_add_options MOZ_MAKE_FLAGS=\"-j%{_smp_build_ncpus}\"" >> .mozconfig

echo "mk_add_options MOZ_SERVICES_SYNC=1" >> .mozconfig
echo "export STRIP=/bin/true" >> .mozconfig

%if %{build_with_pgo}
cp %{SOURCE45} .
. ./run-wayland-compositor
%endif

mkdir -p objdir/_virtualenvs/init_py3
cat > objdir/_virtualenvs/init_py3/pip.conf << EOF
[global]
find-links=`pwd`/mochitest-python
no-index=true
EOF
tar xf %{SOURCE37}

#Use python 3.11 for mach
sed -i -e 's|#!/usr/bin/env python3|#!/usr/bin/env python3.11|' mach

./mach build -v 2>&1 | cat - || exit 1

%if %{build_with_pgo}
kill $MUTTER_PID
%endif

#---------------------------------------------------------------------
%install
# run Firefox test suite
# Do we need it?
# export MACH_NATIVE_PACKAGE_SOURCE=system
%if %{run_firefox_tests}
cp %{SOURCE45} .
. ./run-wayland-compositor

cp %{SOURCE40} %{SOURCE41} %{SOURCE42} %{SOURCE38} %{SOURCE39} %{SOURCE43} %{SOURCE44} .
mkdir -p test_results
./run-tests-wayland || true
./print_results > test_summary.txt 2>&1 || true
./print_failures || true

kill $MUTTER_PID
%endif

# set up our default bookmarks
%if !0%{?flatpak}
cp -p %{default_bookmarks_file} objdir/dist/bin/browser/chrome/browser/content/browser/default-bookmarks.html
%endif

# Make sure locale works for langpacks
cat > objdir/dist/bin/browser/defaults/preferences/firefox-l10n.js << EOF
pref("general.useragent.locale", "chrome://global/locale/intl.properties");
EOF

DESTDIR=%{buildroot} make -C objdir install

mkdir -p %{buildroot}{%{_libdir},%{_bindir},%{_datadir}/applications}

%if %{gnome_shell_search_provider}
# Install Gnome search provider files
mkdir -p %{buildroot}%{_datadir}/gnome-shell/search-providers
cp %{SOURCE34} %{buildroot}%{_datadir}/gnome-shell/search-providers
mkdir -p %{buildroot}%{_datadir}/dbus-1/services
cp %{SOURCE46} %{buildroot}%{_datadir}/dbus-1/services
%endif

%if 0%{?fedora} >= 40
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{SOURCE47}
%else
# We can't use desktop-file-install as it refuses to install firefox.desktop file.
cp %{SOURCE20} %{buildroot}%{_datadir}/applications
%endif

%if 0%{?fedora} < 40
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{SOURCE31}
desktop-file-install --dir %{buildroot}%{_datadir}/applications %{SOURCE29}
%endif

# set up the firefox start script
rm -rf %{buildroot}%{_bindir}/firefox
%if 0%{?fedora} < 40
sed -e 's,/__PREFIX__,%{_prefix},g' -e 's,__APP_NAME__,firefox,g' %{SOURCE21} > %{buildroot}%{_bindir}/firefox
%else
sed -e 's,/__PREFIX__,%{_prefix},g' -e 's,__APP_NAME__,org.mozilla.firefox,g' %{SOURCE21} > %{buildroot}%{_bindir}/firefox
%endif
chmod 755 %{buildroot}%{_bindir}/firefox

%if 0%{?flatpak}
sed -i -e 's|%FLATPAK_ENV_VARS%|export TMPDIR="$XDG_CACHE_HOME/tmp"|' %{buildroot}%{_bindir}/firefox
%else
sed -i -e 's|%FLATPAK_ENV_VARS%||' %{buildroot}%{_bindir}/firefox
%endif

%if 0%{?fedora} < 40
sed -e 's,/__PREFIX__,%{_prefix},g' %{SOURCE30} > %{buildroot}%{_bindir}/firefox-x11
chmod 755 %{buildroot}%{_bindir}/firefox-x11
sed -e 's,/__PREFIX__,%{_prefix},g' %{SOURCE28} > %{buildroot}%{_bindir}/firefox-wayland
chmod 755 %{buildroot}%{_bindir}/firefox-wayland
%endif

install -p -D -m 644 %{SOURCE23} %{buildroot}%{_mandir}/man1/firefox.1

rm -f %{buildroot}/%{mozappdir}/firefox-config
rm -f %{buildroot}/%{mozappdir}/update-settings.ini

for s in 16 22 24 32 48 256; do
    mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps
    cp -p browser/branding/official/default${s}.png \
          %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/firefox.png
done

# Install hight contrast icon
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps
cp -p %{SOURCE25} \
      %{buildroot}%{_datadir}/icons/hicolor/symbolic/apps

echo > %{name}.lang
%if %{with langpacks}
# Extract langpacks, make any mods needed, repack the langpack, and install it.
mkdir -p %{buildroot}%{langpackdir}
tar xf %{SOURCE1}
for langpack in `ls firefox-langpacks/*.xpi`; do
  language=`basename $langpack .xpi`
  extensionID=langpack-$language@firefox.mozilla.org
  mkdir -p $extensionID
  unzip -qq $langpack -d $extensionID
  find $extensionID -type f | xargs chmod 644

  cd $extensionID
  zip -qq -r9mX ../${extensionID}.xpi *
  cd -

  install -m 644 ${extensionID}.xpi %{buildroot}%{langpackdir}
  language=`echo $language | sed -e 's/-/_/g'`
%if 0%{?flatpak}
  echo "%{langpackdir}/${extensionID}.xpi" >> %{name}.lang
%else
  echo "%%lang($language) %{langpackdir}/${extensionID}.xpi" >> %{name}.lang
%endif
done
rm -rf firefox-langpacks

# Install langpack workaround (see #707100, #821169)
function create_default_langpack() {
language_long=$1
language_short=$2
cd %{buildroot}%{langpackdir}
ln -s langpack-$language_long@firefox.mozilla.org.xpi langpack-$language_short@firefox.mozilla.org.xpi
cd -
echo "%%lang($language_short) %{langpackdir}/langpack-$language_short@firefox.mozilla.org.xpi" >> %{name}.lang
}

# Table of fallbacks for each language
# please file a bug at bugzilla.redhat.com if the assignment is incorrect
#create_default_langpack "bn-IN" "bn"
create_default_langpack "es-AR" "es"
create_default_langpack "fy-NL" "fy"
create_default_langpack "ga-IE" "ga"
create_default_langpack "gu-IN" "gu"
create_default_langpack "hi-IN" "hi"
create_default_langpack "hy-AM" "hy"
create_default_langpack "nb-NO" "nb"
create_default_langpack "nn-NO" "nn"
create_default_langpack "pa-IN" "pa"
create_default_langpack "pt-PT" "pt"
create_default_langpack "sv-SE" "sv"
create_default_langpack "zh-TW" "zh"
%endif

mkdir -p %{buildroot}/%{mozappdir}/browser/defaults/preferences

# System config dir
mkdir -p %{buildroot}/%{_sysconfdir}/%{name}/pref

# System extensions
mkdir -p %{buildroot}%{_datadir}/mozilla/extensions/%{firefox_app_id}
mkdir -p %{buildroot}%{_libdir}/mozilla/extensions/%{firefox_app_id}

# Copy over the LICENSE
install -p -c -m 644 LICENSE %{buildroot}/%{mozappdir}

# Use the system hunspell dictionaries
rm -rf %{buildroot}%{mozappdir}/dictionaries
ln -s %{_datadir}/hunspell %{buildroot}%{mozappdir}/dictionaries

# Enable crash reporter for Firefox application
%if %{enable_mozilla_crashreporter}
./mach buildsymbols
sed -i -e "s/\[Crash Reporter\]/[Crash Reporter]\nEnabled=1/" %{buildroot}/%{mozappdir}/application.ini
# Add debuginfo for crash-stats.mozilla.com
mkdir -p %{buildroot}/%{moz_debug_dir}
cp objdir/dist/%{symbols_file_name} %{buildroot}/%{moz_debug_dir}
%endif

%if 0%{?run_firefox_tests}
mkdir -p %{buildroot}/%{version}-%{release}/test_results
cp test_results/* %{buildroot}/%{version}-%{release}/test_results
cp test_summary.txt %{buildroot}/%{version}-%{release}/
cp failures-* %{buildroot}/%{version}-%{release}/ || true
%endif

# Default
cp %{SOURCE12} %{buildroot}%{mozappdir}/browser/defaults/preferences
%if %{?use_xdg_file_portal}
echo 'pref("widget.use-xdg-desktop-portal.file-picker", 1);' >> %{buildroot}%{mozappdir}/browser/defaults/preferences/firefox-redhat-default-prefs.js
%endif

# Copy over run-mozilla.sh
cp build/unix/run-mozilla.sh %{buildroot}%{mozappdir}

# Add distribution.ini
mkdir -p %{buildroot}%{mozappdir}/distribution
cp %{SOURCE26} %{buildroot}%{mozappdir}/distribution

# Install appdata file
mkdir -p %{buildroot}%{_datadir}/metainfo
%if 0%{?fedora} >= 40
sed -e "s/__VERSION__/%{version}/" \
    -e "s/__DATE__/$(date '+%F')/" \
    %{SOURCE48} > %{buildroot}%{_datadir}/metainfo/org.mozilla.firefox.appdata.xml
%else
sed -e "s/__VERSION__/%{version}/" \
    -e "s/__DATE__/$(date '+%F')/" \
    %{SOURCE33} > %{buildroot}%{_datadir}/metainfo/firefox.appdata.xml
%endif

# Remove copied libraries to speed up build
rm -f %{buildroot}%{mozappdirdev}/sdk/lib/libmozjs.so
rm -f %{buildroot}%{mozappdirdev}/sdk/lib/libmozalloc.so
rm -f %{buildroot}%{mozappdirdev}/sdk/lib/libxul.so

# Create a symlink to replace libnssckbi.so with p11-kit-client.so
# instead of p11-kit-trust.so, so that Firefox can see the system
# trust store on the host through the p11-kit RPC protocol.  A symlink
# to libnss3.so is also needed, because Firefox tries to load
# libnssckbi.so from the same directory where libnss3.so is loaded (as
# of Firefox 89).
%if 0%{?flatpak}
ln -sf /usr/lib64/libnss3.so %{buildroot}%{_libdir}/libnss3.so
ln -sf /usr/lib64/pkcs11/p11-kit-client.so %{buildroot}%{_libdir}/libnssckbi.so
%endif
#---------------------------------------------------------------------

# Moves defaults/preferences to browser/defaults/preferences
%pretrans -p <lua>
require 'posix'
require 'os'
if (posix.stat("%{mozappdir}/browser/defaults/preferences", "type") == "link") then
  posix.unlink("%{mozappdir}/browser/defaults/preferences")
  posix.mkdir("%{mozappdir}/browser/defaults/preferences")
  if (posix.stat("%{mozappdir}/defaults/preferences", "type") == "directory") then
    for i,filename in pairs(posix.dir("%{mozappdir}/defaults/preferences")) do
      os.rename("%{mozappdir}/defaults/preferences/"..filename, "%{mozappdir}/browser/defaults/preferences/"..filename)
    end
    f = io.open("%{mozappdir}/defaults/preferences/README","w")
    if f then
      f:write("Content of this directory has been moved to %{mozappdir}/browser/defaults/preferences.")
      f:close()
    end
  end
end

%check
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml

%preun
# is it a final removal?
if [ $1 -eq 0 ]; then
  rm -rf %{mozappdir}/components
  rm -rf %{mozappdir}/extensions
  rm -rf %{mozappdir}/plugins
  rm -rf %{langpackdir}
fi

%if %{with langpacks_subpkg}
%files
%else
%files -f %{name}.lang
%endif
%{_bindir}/firefox
%{mozappdir}/firefox
%{mozappdir}/firefox-bin
%{mozappdir}/glxtest
%doc %{_mandir}/man1/*
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/*
%dir %{_datadir}/mozilla/extensions/*
%dir %{_libdir}/mozilla/extensions/*
%if 0%{?fedora} >= 40
%{_datadir}/applications/org.mozilla.firefox.desktop
%else
%{_datadir}/applications/firefox.desktop
%endif
%if %{gnome_shell_search_provider}
%{_datadir}/dbus-1/services/*
%{_datadir}/gnome-shell/search-providers/*.ini
%endif
%{_datadir}/metainfo/*.appdata.xml
%dir %{mozappdir}
%license %{mozappdir}/LICENSE
%{mozappdir}/browser/chrome
%{mozappdir}/browser/defaults/preferences/firefox-redhat-default-prefs.js
%{mozappdir}/browser/features/*.xpi
%{mozappdir}/distribution/distribution.ini
# That's Windows only
%ghost %{mozappdir}/browser/features/aushelper@mozilla.org.xpi
%if %{without langpacks_subpkg}
%if %{with langpacks}
%dir %{langpackdir}
%endif
%endif
%{mozappdir}/browser/omni.ja
%{mozappdir}/run-mozilla.sh
%{mozappdir}/application.ini
%{mozappdir}/pingsender
%exclude %{mozappdir}/removed-files
%if 0%{?flatpak}
%{_libdir}/libnss3.so
%{_libdir}/libnssckbi.so
%endif
%{_datadir}/icons/hicolor/16x16/apps/firefox.png
%{_datadir}/icons/hicolor/22x22/apps/firefox.png
%{_datadir}/icons/hicolor/24x24/apps/firefox.png
%{_datadir}/icons/hicolor/256x256/apps/firefox.png
%{_datadir}/icons/hicolor/32x32/apps/firefox.png
%{_datadir}/icons/hicolor/48x48/apps/firefox.png
%{_datadir}/icons/hicolor/symbolic/apps/firefox-symbolic.svg
%if %{enable_mozilla_crashreporter}
%{mozappdir}/crashreporter
%{mozappdir}/crashreporter.ini
%{mozappdir}/minidump-analyzer
%{mozappdir}/Throbber-small.gif
%{mozappdir}/browser/crashreporter-override.ini
%endif
%{mozappdir}/*.so
%{mozappdir}/defaults/pref/channel-prefs.js
%{mozappdir}/dependentlibs.list
%{mozappdir}/dictionaries
%{mozappdir}/omni.ja
%{mozappdir}/platform.ini
%{mozappdir}/gmp-clearkey
%{mozappdir}/fonts/TwemojiMozilla.ttf
%ifarch aarch64
%{mozappdir}/v4l2test
%endif
%{mozappdir}/vaapitest
%if !%{?system_nss}
%exclude %{mozappdir}/libnssckbi.so
%endif
%if %{build_with_asan}
%{mozappdir}/llvm-symbolizer
%endif

#---------------------------------------------------------------------

%changelog
* Tue Apr 9 2024 Martin Stransky <stransky@redhat.com>- 125.0-1
- Updated to 125.0

* Thu Apr 4 2024 Martin Stransky <stransky@redhat.com>- 124.0.2-2
- Updated to 124.0.2

* Thu Mar 28 2024 Jan Horak <jhorak@redhat.com> - 124.0.1-4
- Enable rlbox sandboxing

* Mon Mar 25 2024 Martin Stransky <stransky@redhat.com>- 124.0-2
- Reverted IM patch

* Wed Mar 13 2024 Martin Stransky <stransky@redhat.com>- 124.0-1
- Updated to 124.0

* Thu Mar 07 2024 Martin Stransky <stransky@redhat.com>- 123.0.1-1
- Updated to 123.0.1

* Fri Feb 23 2024 Martin Stransky <stransky@redhat.com>- 123.0-2
- Fixed PGO builds and enabled it again.

* Wed Feb 21 2024 Daniel Rusek <mail@asciiwolf.com>- 123.0-2
- Add matching AppStream metadata for org.mozilla.firefox.desktop

* Mon Feb 19 2024 Martin Stransky <stransky@redhat.com>- 123.0-1
- Update to 123.0
- disabled system AV1 due to build issues.

* Tue Feb 13 2024 Martin Stransky <stransky@redhat.com>- 122.0.1-1
- Update to 122.0.1

* Mon Feb 12 2024 Jan Grulich <jgrulich@redhat.com> - 122.0-7
- Backport upstream fixes to PipeWire camera support

* Mon Feb 12 2024 Martin Stransky <stransky@redhat.com>- 122.0-6
- Temporary removed proxy cache (rhbz#2262959)

* Wed Jan 31 2024 Martin Stransky <stransky@redhat.com>- 122.0-5
- Disabled system libvpx due to WebRTC/camera issues (mzbz#1875201)

* Tue Jan 30 2024 Martin Stransky <stransky@redhat.com>- 122.0-4
- Build with --enable-replace-malloc (rhbz#2260766)

* Tue Jan 30 2024 Martin Stransky <stransky@redhat.com>- 122.0-3
- Added version to obsolete firefox-wayland/x11

* Mon Jan 29 2024 Martin Stransky <stransky@redhat.com>- 122.0-2
- Obsolete firefox-wayland and firefox-x11 on Fedora 40+

* Fri Jan 19 2024 Martin Stransky <stransky@redhat.com>- 122.0-1
- Update to 122.0

* Fri Jan 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 121.0.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Fri Jan 12 2024 Fabio Valentini <decathorpe@gmail.com> - 121.0.1-2
- Rebuild for dav1d 1.3.0

* Fri Jan 12 2024 Martin Stransky <stransky@redhat.com>- 121.0.1-1
- Update to 121.0.1
- Fixed Firefox icon on Rawhide

* Tue Jan 02 2024 Martin Stransky <stransky@redhat.com>- 121.0-4
- Really enable proxy cache

* Fri Dec 22 2023 Martin Stransky <stransky@redhat.com>- 121.0-3
- Disabled DBus activations

* Tue Dec 19 2023 Martin Stransky <stransky@redhat.com>- 121.0-2
- Added Wayland proxy cache (mzbz#1743144)

* Mon Dec 18 2023 Martin Stransky <stransky@redhat.com>- 121.0-2
- Enable Gnome Shell Search provider for Fedora 40+
- Don't ship firefox-x11 and firefox-wayland on Fedora 40+

* Mon Dec 18 2023 Martin Stransky <stransky@redhat.com>- 121.0-1
- Updated to 121.0

* Fri Dec 01 2023 Martin Stransky <stransky@redhat.com>- 120.0.1-1
- Updated to 120.0.1

* Mon Nov 27 2023 Martin Stransky <stransky@redhat.com>- 120.0-3
- Add fix for rhbz#2251202

* Mon Nov 20 2023 Martin Stransky <stransky@redhat.com>- 120.0-2
- Updated to 120.0 Build 2

* Tue Nov 14 2023 Martin Stransky <stransky@redhat.com>- 120.0-1
- Updated to 120.0

* Fri Nov 10 2023 Martin Stransky <stransky@redhat.com>- 119.0.1-2
- Updated to 119.0.1

* Tue Nov 07 2023 Martin Stransky <stransky@redhat.com>- 119.0-5
- Added fix for rhbz#2247665

* Mon Nov 06 2023 Martin Stransky <stransky@redhat.com>- 119.0-4
- Added fix for mzbz#1762816

* Mon Oct 30 2023 Jan Horak <jhorak@redhat.com> - 119.0-3
- Enable mozilla crash reporter

* Fri Oct 27 2023 Martin Stransky <stransky@redhat.com>- 119.0-2
- Added fix for mzbz#1861615

* Tue Oct 24 2023 Martin Stransky <stransky@redhat.com>- 119.0-1
- Updated to 119.0

* Tue Oct 10 2023 Martin Stransky <stransky@redhat.com>- 118.0.2-1
- Updated to 118.0.2

* Fri Oct 06 2023 Alessandro Astone <ales.astone@gmail.com> - 118.0.1-7
- Don't include -x11 and -wayland desktop files in the main package (rhbz#2242523)

* Fri Oct 6 2023 Martin Stransky <stransky@redhat.com>- 118.0.1-6
- Removed DBusActivatable flag from desktop file as it crashes KDE (rhbz#2242454).

* Thu Oct 05 2023 Kalev Lember <klember@redhat.com> - 118.0.1-5
- Fix flatpak build

* Mon Oct 2 2023 Martin Stransky <stransky@redhat.com>- 118.0.1-4
- Updated man page

* Mon Oct 2 2023 Martin Stransky <stransky@redhat.com>- 118.0.1-3
- Avoid to launch Firefox by gnome-shell search

* Fri Sep 29 2023 Martin Stransky <stransky@redhat.com>- 118.0.1-2
- Use firefox.desktop again

* Fri Sep 29 2023 Martin Stransky <stransky@redhat.com>- 118.0.1-1
- Updated to 118.0.1

* Wed Sep 27 2023 Neal Gompa <ngompa@fedoraproject.org> - 118.0.1-1
- Use system libraries for AV1, VP8, VP9, and WebP

* Wed Sep 27 2023 Martin Stransky <stransky@redhat.com>- 118.0-2
- Fixed Gnome search provider

* Mon Sep 25 2023 Martin Stransky <stransky@redhat.com>- 118.0-1
- Updated to 118.0

* Thu Sep 14 2023 Adam Williamson <awilliam@redhat.com> - 117.0.1-2
- Pass --with-clang-path to fix build with clang 17 (rhbz#2239047)

* Wed Sep 13 2023 Martin Stransky <stransky@redhat.com>- 117.0.1-1
- Updated to 117.0.1

* Wed Aug 30 2023 Martin Stransky <stransky@redhat.com>- 117.0-2
- Added fix for rhbz#2235654

* Mon Aug 28 2023 Martin Stransky <stransky@redhat.com>- 117.0-1
- Updated to 117.0

* Thu Aug 17 2023 Martin Stransky <stransky@redhat.com>- 116.0.3-1
- Updated to 116.0.3

* Wed Aug 16 2023 Martin Stransky <stransky@redhat.com>- 116.0.2-2
- Added Fedora customization patch

* Mon Aug 7 2023 Martin Stransky <stransky@redhat.com>- 116.0.2-1
- Updated to 116.0.2

* Fri Aug 4 2023 Martin Stransky <stransky@redhat.com>- 116.0.1-1
- Updated to 116.0.1

* Wed Aug 2 2023 Martin Stransky <stransky@redhat.com>- 116.0-3
- Added Canvas/WebGL VA-API playback patch (D167159 / mzbz#1769747)

* Mon Jul 31 2023 Martin Stransky <stransky@redhat.com>- 116.0-2
- Updated to 116.0 Build 2

* Thu Jul 27 2023 Martin Stransky <stransky@redhat.com>- 116.0-1
- Updated to 116.0

* Mon Jul 24 2023 Martin Stransky <stransky@redhat.com>- 115.0.2-4
- Don't set MOZ_GMP_PATH as it's configured by /etc/profile.d/gmpopenh264.sh
  from mozilla-openh264 package.

* Wed Jul 19 2023 Martin Stransky <stransky@redhat.com>- 115.0.2-3
- Fix the previous fix (rhbz#2221317)

* Tue Jul 18 2023 Martin Stransky <stransky@redhat.com>- 115.0.2-2
- Don't overwrite MOZ_GMP_PATH (rhbz#2221317)

* Mon Jul 17 2023 Martin Stransky <stransky@redhat.com>- 115.0.2-1
- Update to 115.0.2

* Tue Jul 11 2023 Dan Horák <dan[at]danny.cz> - 115.0-3
- re-enable ppc64le (rhbz#2212748)

* Thu Jun 29 2023 Martin Stransky <stransky@redhat.com>- 115.0-2
- Update to 115.0
- Disabled LTO due to rhbz#2218885

* Thu Jun 29 2023 Martin Stransky <stransky@redhat.com>- 114.0.2-3
- Enable Elf-hack for PGO builds.

* Thu Jun 22 2023 Martin Stransky <stransky@redhat.com>- 114.0.2-2
- Enable PGO/LTO again.

* Tue Jun 20 2023 Martin Stransky <stransky@redhat.com>- 114.0.2-1
- Update to 114.0.2

* Mon Jun 05 2023 Martin Stransky <stransky@redhat.com>- 114.0-1
- Updated to 114.0
- Disable webrtc on ppc64le
- Disabled ppc64le due t build issues (rhbz#2212748).

* Wed May 24 2023 Martin Stransky <stransky@redhat.com>- 113.0.1-4
- Added patches from 113.0.2
- Added Rust fix for Rawhide (mzbz#1831242).

* Fri May 19 2023 Martin Stransky <stransky@redhat.com>- 113.0.1-3
- Disabled libproxy support due to regressions (rhbz#2207469)

* Tue May 16 2023 Jan Grulich <jgrulich@redhat.com> - 113.0.1-2
- Backport libwebrtc commit 7b0d7f48fb
  Fix fcntl call when duplicating a file descriptor

* Mon May 15 2023 Martin Stransky <stransky@redhat.com>- 113.0.1-1
- Updated to 113.0.1

* Tue May 9 2023 Martin Stransky <stransky@redhat.com>- 113.0-1
- Updated to 113.0

* Thu Apr 27 2023 Martin Stransky <stransky@redhat.com>- 112.0.2-1
- Updated to 112.0.2

* Tue Apr 18 2023 Martin Stransky <stransky@redhat.com>- 112.0.1-1
- Updated to 112.0.1
- Added fix for rhbz#2187000
- Enabled system pixman (by G.Hojda)

* Tue Apr 11 2023 Martin Stransky <stransky@redhat.com>- 112.0-3
- Added wayland window fix mzbz#1827429

* Thu Apr 6 2023 Martin Stransky <stransky@redhat.com>- 112.0-2
- Updated to 112.0 build 2
- don't crash on wayland logging (mzbz#1826583/rhbz#2184842).

* Wed Apr 5 2023 Martin Stransky <stransky@redhat.com>- 112.0-1
- Updated to 112.0

* Wed Apr 5 2023 Martin Stransky <stransky@redhat.com>- 111.0.1-2
- Don't override MOZ_USE_XINPUT2 in startup script (hrbz#2184297) by GalaxyMaster

* Wed Mar 22 2023 Martin Stransky <stransky@redhat.com>- 111.0.1-1
- Updated to 111.0.1

* Tue Mar 21 2023 Jan Grulich <jgrulich@redhat.com> - 111.0-3
- libwebrtc: backport upstream fix/improvement for DmaBuf screen sharing

* Tue Mar 21 2023 Martin Stransky <stransky@redhat.com>- 111.0-2
- Added libproxy support (rhbz#2177806)
- Added build fixes on arm

* Mon Mar 20 2023 Martin Stransky <stransky@redhat.com>- 111.0-1
- Updated to 111.0
- Disabled arm on F36

* Tue Feb 14 2023 Martin Stransky <stransky@redhat.com>- 110.0-3
- Updated to 110.0 build 3

* Mon Feb 13 2023 Martin Stransky <stransky@redhat.com>- 110.0-2
- Added fix for orca

* Thu Feb 9 2023 Martin Stransky <stransky@redhat.com>- 110.0-1
- Updated to 110.0

* Tue Feb 7 2023 Martin Stransky <stransky@redhat.com>- 109.0.1-2
- Rawhide build fix

* Wed Feb 1 2023 Martin Stransky <stransky@redhat.com>- 109.0.1-1
- Updated to 109.0.1
- Added fix for rhbz#2147344 / mzbz#1813500.

* Thu Jan 19 2023 Martin Stransky <stransky@redhat.com>- 109.0-4
- Removed mozbz#1809162

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 109.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Tue Jan 17 2023 Martin Stransky <stransky@redhat.com>- 109.0-2
- Added VA-API fixes mozbz#1809162, mozbz#1801576

* Mon Jan 16 2023 Martin Stransky <stransky@redhat.com>- 109.0-1
- Update to 109.0

* Thu Jan 12 2023 Jan Horak <jhorak@redhat.com> - 108.0.2-1
- Update to 108.0.2

* Mon Jan 09 2023 Kalev Lember <klember@redhat.com> - 108.0.1-4
- Drop conditionals for F35

* Wed Dec 21 2022 Martin Stransky <stransky@redhat.com>- 108.0.1-3
- Added second arch build fix

* Wed Dec 21 2022 Martin Stransky <stransky@redhat.com>- 108.0.1-2
- Added mozbz#1795851 [wayland] Crash buffer size (170x113)
  is not divisible by scale (2)

* Mon Dec 19 2022 Martin Stransky <stransky@redhat.com>- 108.0.1-1
- Update to 108.0.1

* Wed Dec 14 2022 Martin Stransky <stransky@redhat.com>- 108.0-2
- Update to 108.0 Build 2
- Added fix for rhbz#2149821

* Tue Dec 6 2022 Martin Stransky <stransky@redhat.com>- 108.0-1
- Update to 108.0

* Tue Dec 6 2022 Martin Stransky <stransky@redhat.com>- 107.0.1-1
- Update to 107.0.1

* Thu Nov 24 2022 Martin Stransky <stransky@redhat.com>- 107.0-4
- Added fix for mozbz#1779186 - fix VA-API playback artifacts

* Mon Nov 21 2022 Martin Stransky <stransky@redhat.com>- 107.0-3
- Disabled crashreporter

* Mon Nov 21 2022 Jan Horak <jhorak@redhat.com> - 107.0-2
- Enabled mozilla crashreporter again

* Mon Nov 14 2022 Martin Stransky <stransky@redhat.com>- 107.0-1
- Update to 107.0

* Fri Nov 04 2022 Martin Stransky <stransky@redhat.com>- 106.0.4-1
- Update to 106.0.4

* Mon Oct 31 2022 Martin Stransky <stransky@redhat.com>- 106.0.3-1
- Update to 106.0.3

* Sun Oct 23 2022 Martin Stransky <stransky@redhat.com>- 106.0.1-1
- Update to 106.0.1
- Require xdg-desktop-portal when file dialog portal is used.
- Disabled file dialog portals on F37+

* Thu Oct 20 2022 Jan Grulich <jgrulich@redhat.com> - 106.0-2
- Enable upstream WebRTC code for screensharing on Wayland

* Fri Oct 14 2022 Martin Stransky <stransky@redhat.com>- 106.0-1
- Updated to 106.0
- Disabled PGO build due to rhbz#2136401

* Fri Oct 14 2022 Martin Stransky <stransky@redhat.com>- 105.0.2-2
- Fixed crashes on multi-monitor systems (mzbz#1793922)

* Wed Oct 5 2022 Martin Stransky <stransky@redhat.com>- 105.0.2-1
- Updated to 105.0.2

* Fri Sep 30 2022 Martin Stransky <stransky@redhat.com>- 105.0.1-2
- Added fix for mozilla#1791856 / rhbz#2130087

* Thu Sep 22 2022 Martin Stransky <stransky@redhat.com>- 105.0.1-1
- Updated to 105.0.1
- Excluded i686 due to https://bugzilla.mozilla.org/show_bug.cgi?id=1792159,
  https://bugzilla.redhat.com/show_bug.cgi?id=2129720

* Tue Sep 20 2022 Martin Stransky <stransky@redhat.com>- 105.0-1
- Updated to 105.0

* Tue Sep 6 2022 Martin Stransky <stransky@redhat.com>- 104.0.2-1
- Updated to 104.0.2

* Tue Aug 30 2022 Martin Stransky <stransky@redhat.com>- 104.0.1-1
- Updated to 104.0.1

* Tue Aug 23 2022 Kalev Lember <klember@redhat.com> - 104.0-5
- Use constrain_build macro to simplify parallel make handling
- Drop obsolete build conditionals
- Drop unused patches
- Use build_ldflags
- Drop hardened_build option
- Re-enable s390x builds

* Tue Aug 23 2022 Jan Horak <jhorak@redhat.com> - 104.0-4
- Rebuild due to ppc64le fixes

* Mon Aug 22 2022 Eike Rathke <erack@redhat.com> - 104.0-3
- Update to 104.0 respin

* Wed Aug 17 2022 Martin Stransky <stransky@redhat.com>- 104.0-2
- Added build fixes

* Tue Aug 16 2022 Martin Stransky <stransky@redhat.com>- 104.0-1
- Updated to 104.0

* Fri Aug 12 2022 Martin Stransky <stransky@redhat.com>- 103.0.2-1
- Updated to 103.0.2

* Thu Aug 4 2022 Martin Stransky <stransky@redhat.com>- 103.0.1-2
- Added arm build fixes by Gabriel Hojda
- Enable VA-API (rhbz#2115253)

* Tue Aug 2 2022 Martin Stransky <stransky@redhat.com>- 103.0.1-1
- Update to 103.0.1

* Tue Jul 26 2022 Martin Stransky <stransky@redhat.com>- 103.0-1
- Update to 103.0
- Disabled ppc64le due to webrtc build failures (rhbz#2113850)

* Thu Jul 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 102.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Wed Jul 13 2022 Martin Stransky <stransky@redhat.com>- 102.0-3
- Update preference logging.
- Added ARM fixes by Gabriel Hojda.

* Mon Jul 11 2022 Jan Grulich <jgrulich@redhat.com> - 102.0-2
- Backport upstream fixes to WebRTC for screensharing on Wayland

* Tue Jun 28 2022 Martin Stransky <stransky@redhat.com>- 102.0-1
- Updated to 102.0
- Applied patch from https://src.fedoraproject.org/rpms/firefox/pull-request/43

* Mon Jun 27 2022 Martin Stransky <stransky@redhat.com>- 101.0.1-7
- Rebuild

* Fri Jun 17 2022 Martin Stransky <stransky@redhat.com>- 101.0.1-6
- Added fix for mozbz#1774271 - Intel/dmabuf export issues.

* Wed Jun 15 2022 Martin Stransky <stransky@redhat.com>- 101.0.1-5
- Added fix for mozbz#1758948 (AV1 VA-API playback shuttering)

* Tue Jun 14 2022 Martin Stransky <stransky@redhat.com>- 101.0.1-3
- Added fixes for mozbz#1773377 and mozbz#1774075

* Mon Jun 13 2022 Martin Stransky <stransky@redhat.com>- 101.0.1-2
- Fix WebGL mem leaks (mzbz#1773968)

* Thu Jun 9 2022 Martin Stransky <stransky@redhat.com>- 101.0.1-1
- Updated to 101.0.1
- More VA-API sandbox fixes (mzbz#1769182)
- Fixed OpenH264 decode (rhbz#2094319)

* Tue Jun 7 2022 Martin Stransky <stransky@redhat.com>- 101.0-2
- Enabled VA-API by default (+ added VA-API fixes from upstream)
- Fixed WebGL performance on NVIDIA drivers (mzbz#1735929)

* Mon May 30 2022 Martin Stransky <stransky@redhat.com>- 101.0-1
- Updated to 101.0

* Wed May 25 2022 Martin Stransky <stransky@redhat.com>- 100.0.2-2
- Added fix for mzbz#1771104

* Fri May 20 2022 Martin Stransky <stransky@redhat.com>- 100.0.2-1
- Updated to 100.0.2

* Wed May 18 2022 Martin Stransky <stransky@redhat.com>- 100.0.1-1
- Updated to 100.0.1

* Mon May 16 2022 Jan Horak <jhorak@redhat.com> - 100.0-6
- Fix spellchecker.dictionary_path of F36+

* Tue May 10 2022 Jan Horak <jhorak@redhat.com> - 100.0-5
- Fix crashes on f36 multimonitor setup and too big profile manager

* Mon May 9 2022 Martin Stransky <stransky@redhat.com>- 100.0-4
- Added fix for mozbz#1767916.

* Thu May 5 2022 Martin Stransky <stransky@redhat.com>- 100.0-3
- Removed Fedora user agent patch (rhbz#2081791).

* Tue May 3 2022 Martin Stransky <stransky@redhat.com>- 100.0-2
- Added fix for mozbz#1759137

* Mon May 2 2022 Martin Stransky <stransky@redhat.com>- 100.0-1
- Updated to 100.0

* Thu Apr 28 2022 Jan Horak <jhorak@redhat.com> - 99.0.1-2
- Fixing bookmark install location - rhbz#2054953

* Wed Apr 13 2022 Martin Stransky <stransky@redhat.com> - 99.0.1-1
- Updated to 99.0.1

* Wed Apr 6 2022 Martin Stransky <stransky@redhat.com> - 99.0-1
- Updated to 99.0

* Thu Mar 31 2022 Martin Stransky <stransky@redhat.com> - 98.0.2-1
- Updated to 98.0.2

* Wed Mar 30 2022 Jan Grulich <jgrulich@redhat.com> - 98.0-4
- Wayland screensharing: avoid potential crash when cursor metadata are not set

* Wed Mar 16 2022 Martin Stransky <stransky@redhat.com> - 98.0-3
- Added a workaround for rhbz#2063961

* Wed Mar 2 2022 Martin Stransky <stransky@redhat.com> - 98.0-2
- Added support for ffmpeg 5.0
- Spec tweaks
- Updated to Build 3

* Tue Mar 1 2022 Martin Stransky <stransky@redhat.com> - 98.0-1
- Updated to 98.0

* Mon Feb 21 2022 Jan Grulich <jgrulich@redhat.com> - 97.0.1-2
- Backport WebRTC changes to PipeWire/Wayland screen sharing support

* Fri Feb 18 2022 Martin Stransky <stransky@redhat.com> - 97.0.1-1
- Updated to 97.0.1
- GCC 12 build fixes

* Tue Feb 8 2022 Martin Stransky <stransky@redhat.com> - 97.0-1
- Updated to 97.0

* Mon Jan 31 2022 Martin Stransky <stransky@redhat.com> - 96.0.3-1
- Updated to 96.0.3

* Tue Jan 25 2022 Parag Nemade <pnemade AT redhat DOT com> - 96.0.1-3
- Update hunspell-dir path
  F36 Change https://fedoraproject.org/wiki/Changes/Hunspell_dictionary_dir_change

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 96.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Tue Jan 18 2022 Martin Stransky <stransky@redhat.com> - 96.0.1-1
- Updated to 96.0.1

* Tue Jan 11 2022 Martin Stransky <stransky@redhat.com> - 96.0-1
- Updated to 96.0

* Sat Jan 08 2022 Miro Hrončok <mhroncok@redhat.com> - 95.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Changes/LIBFFI34

* Thu Dec 23 2021 Martin Stransky <stransky@redhat.com> - 95.0.2-4
- Added fix fox mozbz#1744896 (VSync)

* Wed Dec 22 2021 Martin Stransky <stransky@redhat.com> - 95.0.2-3
- Added Fedora 36 build fix (mzbz#1745560)

* Mon Dec 20 2021 Martin Stransky <stransky@redhat.com> - 95.0.2-1
- Updated to 95.0.2
- Enabled Wayland on KDE by default

* Thu Dec 9 2021 Martin Stransky <stransky@redhat.com> - 95.0-2
- Updated symbolic icon (rhbz#2028939)

* Fri Dec 3 2021 Martin Stransky <stransky@redhat.com> - 95.0-1
- Updated to 95.0

* Fri Nov 19 2021 Martin Stransky <stransky@redhat.com> - 94.0-2
- Added fix for mozbz#1739924 / rhbz#2020981.

* Mon Nov 1 2021 Martin Stransky <stransky@redhat.com> - 94.0-1
- Updated to 94.0

* Thu Oct 07 2021 Martin Stransky <stransky@redhat.com> - 93.0-2
- Require NSS 3.70

* Wed Sep 29 2021 Martin Stransky <stransky@redhat.com> - 93.0-1
- Updated to 93.0

* Mon Sep 27 2021 Martin Stransky <stransky@redhat.com> - 92.0.1-1
- Updated to 92.0.1

* Mon Sep 13 2021 Martin Stransky <stransky@redhat.com> - 92.0-3
- Added fix for mozbz#1725828

* Thu Sep 9 2021 Martin Stransky <stransky@redhat.com> - 92.0-2
- Disable test

* Fri Sep 3 2021 Martin Stransky <stransky@redhat.com> - 92.0-1
- Updated to 92.0
- Added fix for mozbz#1728749
- Added fix for mozbz#1708709

* Thu Aug 26 2021 Martin Stransky <stransky@redhat.com> - 91.0.2-1
- Updated to 91.0.2

* Mon Aug 23 2021 Martin Stransky <stransky@redhat.com> - 91.0.1-2
- Set %%build_with_clang automatically based on %%toolchain
  by Timm Bäder <tbaeder@redhat.com>
- Updated Fedora UA patch by Eric Engestrom
  (https://src.fedoraproject.org/rpms/firefox/pull-request/21)
- Added fix for mozbz#1726515

* Mon Aug 23 2021 Martin Stransky <stransky@redhat.com> - 91.0.1-1
- Updated to 91.0.1

* Tue Aug 10 2021 Martin Stransky <stransky@redhat.com> - 91.0-1
- Updated to 91.0

* Wed Aug 04 2021 Martin Stransky <stransky@redhat.com> - 90.0.2-2
- Added fix for rhbz#1988841 - Allow unsigned extensions when installed
  under non-user-writable dirs.

* Thu Jul 22 2021 Martin Stransky <stransky@redhat.com> - 90.0.2-1
- Updated to 90.0.2

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> - 90.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jul 21 2021 Martin Stransky <stransky@redhat.com> - 90.0.1-1
- Updated to 90.0.1
- Added fixes to build on rawhide

* Thu Jul 15 2021 Martin Stransky <stransky@redhat.com> - 90.0-3
- Disabled Wayland backend on KDE due to
  https://bugzilla.mozilla.org/show_bug.cgi?id=1714132

* Tue Jul 13 2021 Martin Stransky <stransky@redhat.com> - 90.0-2
- Added xorg-x11-server-Xwayland dependency for Mutter

* Mon Jul 12 2021 Martin Stransky <stransky@redhat.com> - 90.0-1
- Updated to 90.0

* Mon Jul 12 2021 Daiki Ueno <dueno@redhat.com> - 89.0.2-3
- flatpak: Enable loading system trust store on the host (rhbz#1766340)

* Wed Jun 30 2021 Martin Stransky <stransky@redhat.com> - 89.0.2-2
- Added fix for mozbz#1715254 (rhbz#1976892).

* Thu Jun 24 2021 Martin Stransky <stransky@redhat.com> - 89.0.2-1
- Updated to latest upstream (89.0.2)

* Mon Jun 14 2021 Martin Stransky <stransky@redhat.com> - 89.0-2
- Added fix for mozbz#1646135

* Tue Jun 1 2021 Martin Stransky <stransky@redhat.com> - 89.0-1
- Updated to latest upstream (89.0)

* Mon May 10 2021 Martin Stransky <stransky@redhat.com> - 88.0.1-1
- Updated to latest upstream (88.0.1)

* Tue May 4 2021 Martin Stransky <stransky@redhat.com> - 88.0-8
- Added fix for mozbz#1705048.

* Fri Apr 30 2021 Martin Stransky <stransky@redhat.com> - 88.0-7
- Added pciutils-libs req (rhbz#1955338)
- Enabled Wayland on KDE (rhbz#1922608)

* Tue Apr 27 2021 Martin Stransky <stransky@redhat.com> - 88.0-6
- Test fix.

* Fri Apr 23 2021 Martin Stransky <stransky@redhat.com> - 88.0-5
- Added fix for mozbz#1580595 - mouse pointer lock.
- Another test update.

* Thu Apr 22 2021 Martin Stransky <stransky@redhat.com> - 88.0-4
- Run with mochitest test suite.

* Thu Apr 22 2021 Martin Stransky <stransky@redhat.com> - 88.0-3
- Build with crashreporter enabled.

* Wed Apr 21 2021 Martin Stransky <stransky@redhat.com> - 88.0-2
- Added clipboard fix mzbz#1703763.

* Mon Apr 19 2021 Martin Stransky <stransky@redhat.com> - 88.0-1
- Update to 88.0

* Mon Apr 12 2021 Martin Stransky <stransky@redhat.com> - 87.0-12
- Added fix for mozbz#1701089 (Widevine playback issues).

* Tue Apr 6 2021 Martin Stransky <stransky@redhat.com> - 87.0-11
- Enabled xpcshell/crashtests on Wayland.

* Sat Apr 3 2021 Martin Stransky <stransky@redhat.com> - 87.0-10
- Wayland testing again.

* Thu Apr 1 2021 Martin Stransky <stransky@redhat.com> - 87.0-9
- Added fix for mozbz#1702606 / rhbz#1936071
- Switched tests back to X11 due to massive failures.

* Thu Apr 1 2021 Martin Stransky <stransky@redhat.com> - 87.0-8
- Run testsuite on Wayland on Fedora 33+
- Spec cleanup

* Wed Mar 31 2021 Martin Stransky <stransky@redhat.com> - 87.0-7
- Added fix for mozbz#1693472 - Wayland/KDE rendering issues.

* Tue Mar 30 2021 Jonathan Wakely <jwakely@redhat.com> - 87.0-6
- Rebuilt for removed libstdc++ symbol (#1937698)

* Tue Mar 30 2021 Martin Stransky <stransky@redhat.com> - 87.0-5
- Reftest fix

* Fri Mar 26 2021 Martin Stransky <stransky@redhat.com> - 87.0-4
- More test fixes
- Enabled ppc64le
- Disabled crashreporter on Fedora 34+

* Wed Mar 24 2021 Martin Stransky <stransky@redhat.com> - 87.0-2
- More test fixes

* Tue Mar 23 2021 Martin Stransky <stransky@redhat.com> - 87.0-1
- Disabled ARM due to build failures
- Updated to 87.0

* Sat Mar 13 2021 Martin Stransky <stransky@redhat.com> - 86.0.1-2
- Enabled ARM

* Fri Mar 12 2021 Martin Stransky <stransky@redhat.com> - 86.0.1-1
- Update to latest upstream (86.0.1)

* Wed Mar 10 2021 Martin Stransky <stransky@redhat.com> - 86.0-8
- Temporary disable ppc64le/Fedora 35 due to
  https://bugzilla.redhat.com/show_bug.cgi?id=1933742

* Wed Mar 3 2021 Martin Stransky <stransky@redhat.com> - 86.0-7
- Added fix for mozbz#1694670

* Mon Mar 1 2021 Martin Stransky <stransky@redhat.com> - 86.0-6
- Run xpcshell tests sequential
- Test fixes

* Mon Mar 1 2021 Martin Stransky <stransky@redhat.com> - 86.0-4
- Enable Wayland backend only when Wayland display is set.

* Mon Mar 1 2021 Martin Stransky <stransky@redhat.com> - 86.0-3
- Added icecat-78.7.1-fix_error_template_with_C_linkage.patch to
  build on F34+

* Fri Feb 26 2021 Martin Stransky <stransky@redhat.com> - 86.0-2
- Built with system nss

* Tue Feb 23 2021 Martin Stransky <stransky@redhat.com> - 86.0-1
- Update to 86.0
- Disabled Wayland backend on KDE/Plasma

* Tue Feb 23 2021 Martin Stransky <stransky@redhat.com> - 85.0.1-2
- Fixed some reftest run in Mock

* Mon Feb 08 2021 Martin Stransky <stransky@redhat.com> - 85.0.1-1
- Updated to 85.0.1

* Wed Feb 03 2021 Dan Horák <dan[at]danny.cz> - 85.0-11
- Fix parameter passing on ppc64le (mozb#1690152)

* Tue Feb 02 2021 Kalev Lember <klember@redhat.com> - 85.0-10
- Remove gtk2 support as flash plugin is no longer supported

* Sat Jan 30 2021 Martin Stransky <stransky@redhat.com> - 85.0-9
- Enable WebRender on KDE/Wayland and AMD/Intel drivers.

* Sat Jan 30 2021 Martin Stransky <stransky@redhat.com> - 85.0-8
- Enable Wayland backend on Fedora 34/KDE/Plasma (and other compositors)
  by default (https://bugzilla.redhat.com/show_bug.cgi?id=1922608).

* Fri Jan 29 2021 Martin Stransky <stransky@redhat.com> - 85.0-7
- Added clipboard fix mozbz#1631061.

* Thu Jan 28 2021 Kalev Lember <klember@redhat.com> - 85.0-6
- Make provides/requires filtering smarter/automatic (rhbz#1582116)
- Drop dbus-glib requires that are now automatically generated again

* Thu Jan 28 2021 Martin Stransky <stransky@redhat.com> - 85.0-5
- Add dbus-glib requires.

* Tue Jan 26 2021 Martin Stransky <stransky@redhat.com> - 85.0-4
- Added fix for mozbz#1679933 - startup crash

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 85.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Jan 20 2021 Martin Stransky <stransky@redhat.com> - 85.0-2
- Update to 85.0.

* Wed Jan 20 2021 Jan Horak <jhorak@redhat.com> - 84.0.2-8
- Fixing package requires/provides

* Tue Jan 19 2021 Martin Stransky <stransky@redhat.com> - 84.0.2-7
- Fixed mzbz#164294 regression.

* Fri Jan 15 2021 Martin Stransky <stransky@redhat.com> - 84.0.2-6
- Added WebRender fix (mozbz#1681107).

* Thu Jan 14 2021 Martin Stransky <stransky@redhat.com> - 84.0.2-5
- Removed some failing tests.
- Spec file tweaks.

* Tue Jan 12 2021 Martin Stransky <stransky@redhat.com> - 84.0.2-4
- Enabled LTO in Firefox build system.

* Tue Jan 12 2021 Martin Stransky <stransky@redhat.com> - 84.0.2-3
- Removed failing xpcshell/reftests, test tweaks.

* Mon Jan 11 2021 Martin Stransky <stransky@redhat.com> - 84.0.2-2
- Added a workaround for rhbz#1908018

* Wed Jan 6 2021 Martin Stransky <stransky@redhat.com> - 84.0.2-1
- Updated to 84.0.2

* Tue Jan 05 2021 Jan Horak <jhorak@redhat.com> - 84.0.1-5
- Removing requires/provides of the bundled libraries

* Mon Jan 4 2021 Martin Stransky <stransky@redhat.com> - 84.0.1-4
- Enabled tests

* Mon Jan 4 2021 Martin Stransky <stransky@redhat.com> - 84.0.1-3
- Enabled armv7hl arch on rawhide

* Wed Dec 23 2020 Martin Stransky <stransky@redhat.com> - 84.0.1-2
- Reverted mzbz#1631061 due to clipboard regressions
- Disabled armv7hl build on rawhide due to rhbz#1910277
- Build with system nss on rawhide (rhbz#1908791).

* Tue Dec 22 2020 Martin Stransky <stransky@redhat.com> - 84.0.1-1
- Updated to 84.0.1

* Sun Dec 20 2020 Miro Hrončok <mhroncok@redhat.com> - 84.0-7
- Filter out private libraries provides
- Fixes: rhbz#1908791

* Thu Dec 17 2020 Martin Stransky <stransky@redhat.com> - 84.0-6
- Disable PGO on Rawhide due to build issues
- Disable system nss on Rawhide due to rhbz#1908018
- Enabled system nss on Fedora 33/32

* Wed Dec 16 2020 Martin Stransky <stransky@redhat.com> - 84.0-5
- Build with tests enabled

* Wed Dec 16 2020 Martin Stransky <stransky@redhat.com> - 84.0-4
- Disabled LTO due to massive test failures

* Wed Dec 16 2020 Martin Stransky <stransky@redhat.com> - 84.0-3
- Updated to Firefox 84 Build 3
- Disabled system nss due to addon breakage (rhbz#1908018).

* Wed Dec 9 2020 Martin Stransky <stransky@redhat.com> - 83.0-15
- Enabled tests everywhere
- Enabled crash reporter

* Tue Dec 1 2020 Martin Stransky <stransky@redhat.com> - 83.0-14
- Enabled LTO

* Tue Dec 1 2020 Martin Stransky <stransky@redhat.com> - 83.0-13
- Added fix for mozbz#1672139

* Tue Dec 1 2020 Martin Stransky <stransky@redhat.com> - 83.0-12
- More mochitest fixes

* Mon Nov 30 2020 Martin Stransky <stransky@redhat.com> - 83.0-11
- Mochitest tweaking

* Sat Nov 28 2020 Martin Stransky <stransky@redhat.com> - 83.0-10
- Added fix for mzbz#1678680

* Wed Nov 25 2020 Martin Stransky <stransky@redhat.com> - 83.0-9
- Added mochitest test files

* Wed Nov 25 2020 Martin Stransky <stransky@redhat.com> - 83.0-8
- Added fix for rhbz#1900542

* Wed Nov 25 2020 Martin Stransky <stransky@redhat.com> - 83.0-7
- Export MOZ_GMP_PATH from /usr/bin/firefox script
  (https://pagure.io/fedora-workstation/issue/126)

* Tue Nov 24 2020 Martin Stransky <stransky@redhat.com> - 83.0-6
- Fix mochitest

* Wed Nov 18 2020 Martin Stransky <stransky@redhat.com> - 83.0-5
- Build with tests enabled

* Wed Nov 18 2020 Martin Stransky <stransky@redhat.com> - 83.0-4
- Enable all arches

* Fri Nov 13 2020 Martin Stransky <stransky@redhat.com> - 83.0-3
- Updated to 83.0 Build 2

* Thu Nov 12 2020 Martin Stransky <stransky@redhat.com> - 83.0-1
- Updated to 83.0
- Updated PipeWire patches from mozbz#1672944

* Tue Nov 10 2020 Martin Stransky <stransky@redhat.com> - 82.0.3-2
- Added fix for mozbz#1885133

* Mon Nov 9 2020 Martin Stransky <stransky@redhat.com> - 82.0.3-1
- Updated to 82.0.3

* Mon Nov 9 2020 Kalev Lember <klember@redhat.com> - 82.0.2-7
- Include date in appdata release tags

* Fri Nov 6 2020 Tomas Popela <tpopela@redhat.com> - 82.0.2-6
- Re-enable s390x buils by backporting a change from Thunderbird
  https://src.fedoraproject.org/rpms/thunderbird/c/5f0bec1b5b79e117cc469710afbfa4d008af9c29?branch=master

* Tue Nov 3 2020 Martin Stransky <stransky@redhat.com> - 82.0.2-5
- Added mozilla-openh264 dependency to play H264 clips out of the box
- Updated Firefox tests

* Tue Nov 3 2020 Martin Stransky <stransky@redhat.com> - 82.0.2-3
- Disabled LTO again.

* Tue Nov 3 2020 Martin Stransky <stransky@redhat.com> - 82.0.2-2
- NSS debug build

* Thu Oct 29 2020 Martin Stransky <stransky@redhat.com> - 82.0.2-1
- Updated to 82.0.2
- Removed mzbz#1668771 due to rhbz#1888920

* Wed Oct 28 2020 Martin Stransky <stransky@redhat.com> - 82.0.1-1
- Updated to 82.0.1

* Tue Oct 27 2020 Martin Stransky <stransky@redhat.com> - 82.0-8
- Added fix for mozbz#1673313

* Tue Oct 27 2020 Martin Stransky <stransky@redhat.com> - 82.0-7
- Added fix for rawhide crashes (rhbz#1891234)

* Sat Oct 24 2020 Martin Stransky <stransky@redhat.com> - 82.0-6
- Enable LTO

* Tue Oct 20 2020 Martin Stransky <stransky@redhat.com> - 82.0-5
- Added fix for rhbz#1889742 - Typo in /usr/bin/firefox

* Mon Oct 19 2020 Martin Stransky <stransky@redhat.com> - 82.0-4
- Updated openh264 patch to use keyframes from contained
  for openh264 only.

* Mon Oct 19 2020 Martin Stransky <stransky@redhat.com> - 82.0-3
- Added ELN build fixes

* Thu Oct 15 2020 Martin Stransky <stransky@redhat.com> - 82.0-2
- Updated SELinux relabel setup (rhbz#1731371)

* Thu Oct 15 2020 Martin Stransky <stransky@redhat.com> - 82.0-1
- Updated to 82.0 Build 2

* Thu Oct 15 2020 Martin Stransky <stransky@redhat.com> - 81.0.2-3
- Added experimental openh264 seek patch (mzbz#1670333)

* Mon Oct 12 2020 Martin Stransky <stransky@redhat.com> - 81.0.2-2
- Added a partial fox for rhbz#1886722

* Mon Oct 12 2020 Martin Stransky <stransky@redhat.com> - 81.0.2-1
- Updated to latest upstream - 81.0.2

* Thu Oct 8 2020 Martin Stransky <stransky@redhat.com> - 81.0.1-9
- Added an updated fix for mozbz#1656727

* Thu Oct 8 2020 Martin Stransky <stransky@redhat.com> - 81.0.1-8
- Added fixes for mozbz#1634404, mozbz#1669495

* Thu Oct 8 2020 Martin Stransky <stransky@redhat.com> - 81.0.1-7
- Removed mozbz#1656727 as it causes a regression rhbz#1886243

* Wed Oct 7 2020 Martin Stransky <stransky@redhat.com> - 81.0.1-6
- PGO patch update
- Added fix for mzbz#1669442 (LTO builds)

* Mon Oct 5 2020 Martin Stransky <stransky@redhat.com> - 81.0.1-5
- Added fix for mozbz#1656727

* Fri Oct 2 2020 Martin Stransky <stransky@redhat.com> - 81.0.1-4
- Added fix for mozbz#1668771

* Thu Oct 1 2020 Martin Stransky <stransky@redhat.com> - 81.0.1-3
- Added fix for mozbz#1661192

* Thu Oct 1 2020 Martin Stransky <stransky@redhat.com> - 81.0.1-2
- Added fix for mozbz#1640567
- Enable PGO

* Wed Sep 30 2020 Martin Stransky <stransky@redhat.com> - 81.0.1-1
- Updated to 81.0.1

* Wed Sep 30 2020 Martin Stransky <stransky@redhat.com> - 81.0-9
- Disabled openh264 download
- Removed fdk-aac-free dependency (rhbz#1883672)
- Enabled LTO

* Sat Sep 26 2020 Dan Horák <dan[at]danny.cz> - 81.0-8
- Re-enable builds for ppc64le

* Fri Sep 25 2020 Martin Stransky <stransky@redhat.com> - 81.0-7
- Added openh264 fixes

* Wed Sep 23 2020 Martin Stransky <stransky@redhat.com> - 81.0-6
- Added fix for rhbz#1731371

* Tue Sep 22 2020 Kalev Lember <klember@redhat.com> - 81.0-5
- Re-enable builds for armv7hl and aarch64 architectures

* Tue Sep 22 2020 Kalev Lember <klember@redhat.com> - 81.0-4
- Disable LTO to work around firefox build failing in F33+

* Mon Sep 21 2020 Martin Stransky <stransky@redhat.com> - 81.0-3
- Updated to 81.0 Build 2
- Updated firefox-disable-ffvpx-with-vapi patch
- Deleted old changelog entries

* Thu Sep 17 2020 Martin Stransky <stransky@redhat.com> - 81.0-2
- Added upstream patches mzbz#1665324 mozbz#1665329
- Updated requested nss version to 3.56

* Tue Sep 15 2020 Martin Stransky <stransky@redhat.com> - 81.0-1
- Updated to 81.0

* Thu Sep 10 2020 Martin Stransky <stransky@redhat.com> - 80.0.1-3
- Test build for all arches.

* Fri Sep 4 2020 Martin Stransky <stransky@redhat.com> - 80.0.1-2
- Added patch for mozbz#1875469

* Tue Sep 1 2020 Martin Stransky <stransky@redhat.com> - 80.0.1-1
- Updated to 80.0.1

* Tue Aug 18 2020 Martin Stransky <stransky@redhat.com> - 80.0-1
- Updated to 80.0 Build 2
- Go back to gcc
- Disabled WebGL dmabuf backend due to reported errors
  (mzbz#1655323, mozbz#1656505).

* Tue Aug 18 2020 Martin Stransky <stransky@redhat.com> - 79.0-6
- Enabled pgo
- Build with clang

* Tue Aug 4 2020 Martin Stransky <stransky@redhat.com> - 79.0-5
- Added upstream fix for mozbz#1656436.

* Mon Aug 3 2020 Martin Stransky <stransky@redhat.com> - 79.0-4
- Updated fix for mozbz#1645671

* Thu Jul 30 2020 Martin Stransky <stransky@redhat.com> - 79.0-3
- Added VA-API fix for mozbz#1645671

* Wed Jul 29 2020 Martin Stransky <stransky@redhat.com> - 79.0-2
- Try to enable armv7hl again.
- Disabled ppc64le due to cargo crash (rhbz#1862012).

* Mon Jul 27 2020 Martin Stransky <stransky@redhat.com> - 79.0-1
- Update to 79.0
- Disabled PGO due to rhbz#1849165 (gcc internal error).

* Mon Jul 27 2020 Fedora Release Engineering <releng@fedoraproject.org> - 78.0.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Thu Jul 23 2020 Frantisek Zatloukal <fzatlouk@redhat.com> - 78.0-4
- Use python3 instead of python2 for build

* Tue Jul 21 2020 Martin Stransky <stransky@redhat.com> - 78.0-3
- Added fix for mozbz#1651701/rhbz#1855730

* Fri Jul 10 2020 Jan Horak <jhorak@redhat.com> - 78.0.2-2
- Fixing clang build - linker setup

* Thu Jul 09 2020 Jan Horak <jhorak@redhat.com> - 78.0.2-1
- Update to 78.0.2 build2

* Wed Jul 01 2020 Jan Horak <jhorak@redhat.com> - 78.0.1-1
- Update to 78.0.1 build1

* Wed Jul 1 2020 Martin Stransky <stransky@redhat.com> - 78.0-2
- Add 'Open the Profile Manager' desktop file entry

* Mon Jun 29 2020 Jan Horak <jhorak@redhat.com> - 78.0-1
- Update to 78.0 build2

* Tue Jun 23 2020 Martin Stransky <stransky@redhat.com> - 77.0.1-3
- Build with PGO/LTO again.

* Wed Jun 03 2020 Jan Horak <jhorak@redhat.com> - 77.0.1-2
- Update to 77.0.1 build1

* Wed Jun 03 2020 Jan Horak <jhorak@redhat.com> - 77.0.1-1
- Fixing pipewire patch
- New upstream version (77.0.1)

* Tue Jun 2 2020 Martin Stransky <stransky@redhat.com> - 77.0-2
- Rebuild with updated langpacks (rhbz#1843028).

* Fri May 29 2020 Martin Stransky <stransky@redhat.com> - 77.0-1
- Updated to Firefox 77.0

* Mon May 25 2020 Martin Stransky <stransky@redhat.com> - 76.0.1-7
- Added fix for mozbz#1632456

* Mon May 25 2020 Martin Stransky <stransky@redhat.com> - 76.0.1-6
- Added fix for mozbz#1634213

* Mon May 25 2020 Martin Stransky <stransky@redhat.com> - 76.0.1-5
- Added fix for mozbz#1619882 - video flickering when va-api is used.

* Thu May 21 2020 Jan Grulich <jgrulich@redhat.com> - 76.0.1-4
- Add support for PipeWire 0.3

* Wed May 20 2020 Peter Robinson <pbrobinson@fedoraproject.org> - 76.0.1-3
- Build aarch64 again so aarch64 users get updates

* Wed May 13 2020 Martin Stransky <stransky@redhat.com> - 76.0.1-2
- Added extra va-api frames to vp8/9 decoder.

* Fri May 8 2020 Martin Stransky <stransky@redhat.com> - 76.0.1-1
- Updated to 76.0.1

* Thu May 7 2020 Martin Stransky <stransky@redhat.com> - 76.0-3
- Disable ffvpx when va-api is enabled.

* Tue May 05 2020 Jan Horak <jhorak@redhat.com> - 76.0-2
- Don't use google safe browsing api key for the geolocation

* Sun May 3 2020 Martin Stransky <stransky@redhat.com> - 76.0-1
- Updated to 76.0

* Thu Apr 23 2020 Martin Stransky <stransky@redhat.com> - 75.0-3
- Added fix for mozilla bug #1527976 (browser D&D)

* Tue Apr 14 2020 Jan Horak <jhorak@redhat.com> - 75.0-2
- Removed gconf-2.0 build requirement

* Mon Apr 06 2020 Martin Stransky <stransky@redhat.com> - 75.0-1
- Updated to 75.0

* Mon Apr 06 2020 Martin Stransky <stransky@redhat.com> - 74.0.1-3
- Added fix for mozbz#1627469

* Mon Apr 06 2020 Jan Horak <jhorak@redhat.com> - 74.0.1-2
- Fixing pipewire patch

* Sat Apr 4 2020 Martin Stransky <stransky@redhat.com> - 74.0.1-1
- Updated to latest upstream
- Added fix for mozbz#1624745

* Wed Apr 1 2020 Martin Stransky <stransky@redhat.com> - 74.0-14
- Added fixes to gnome shell search provider

* Tue Mar 31 2020 Jan Horak <jhorak@redhat.com> - 74.0-13
- Allow addons sideload to fix missing langpacks issues

* Thu Mar 19 2020 Martin Stransky <stransky@redhat.com> - 74.0-12
- Added fix for rhbz#1814850 by Daniel Rusek

* Tue Mar 17 2020 Martin Stransky <stransky@redhat.com> - 74.0-11
- Added fix for mozbz#1623106

* Tue Mar 17 2020 Martin Stransky <stransky@redhat.com> - 74.0-9
- Added fix for mozbz#1623060

* Tue Mar 17 2020 Jan Grulich <jgrulich@redhat.com> - 74-0-8
- Add support for window sharing

* Mon Mar 16 2020 Martin Stransky <stransky@redhat.com> - 74.0-7
- Use D-Bus remote exclusively for both X11 and Wayland backends
  when WAYLAND_DISPLAY is present.

* Fri Mar 13 2020 Martin Stransky <stransky@redhat.com> - 74.0-6
- Added fix for mozbz#1615098

* Thu Mar 12 2020 Martin Stransky <stransky@redhat.com> - 74.0-5
- Added fix for mozbz#1196777

* Tue Mar 10 2020 Kalev Lember <klember@redhat.com> - 74.0-4
- Remove unused libIDL build dep
- Disabled arm due to build failures

* Tue Mar 10 2020 Martin Stransky <stransky@redhat.com> - 74.0-3
- Update to 74.0 Build 3

* Mon Mar 09 2020 Martin Stransky <stransky@redhat.com> - 74.0-2
- Update to 74.0 Build 2

* Tue Mar 03 2020 Martin Stransky <stransky@redhat.com> - 74.0-1
- Update to 74.0 Build 1
- Added mozbz#1609538

* Mon Feb 24 2020 Martin Stransky <stransky@redhat.com> - 73.0.1-4
- Using pipewire-0.2 as buildrequire
- Added armv7hl fixes by Gabriel Hojda

* Mon Feb 24 2020 Martin Stransky <stransky@redhat.com> - 73.0.1-2
- Fixed Bug 1804787 - Some .desktop menu entries unlocalized

* Thu Feb 20 2020 Martin Stransky <stransky@redhat.com> - 73.0.1-1
- Update to 73.0.1

* Tue Feb 11 2020 Jan Horak <jhorak@redhat.com> - 73.0-1
- Update to 73.0 build3

* Tue Feb 04 2020 Kalev Lember <klember@redhat.com> - 72.0.2-3
- Fix various issues with appdata, making the validation pass again
- Validate appdata during the build
- Make sure the release tag in appdata is in sync with the package version

* Tue Jan 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 72.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Mon Jan 20 2020 Jan Horak <jhorak@redhat.com> - 72.0.2-1
- Update to 72.0.2 build1

* Wed Jan 15 2020 Jan Horak <jhorak@redhat.com> - 72.0.1-2
- Added fix for wrong cursor offset of popup windows and bumped required nss
  version

* Wed Jan 08 2020 Jan Horak <jhorak@redhat.com> - 72.0.1-1
- Update to 72.0.1 build1

* Mon Jan 06 2020 Jan Horak <jhorak@redhat.com> - 72.0-2
- Update to 72.0 build4

* Fri Jan 03 2020 Jan Horak <jhorak@redhat.com> - 72.0-1
- Update to 72.0 build3

* Wed Dec 18 2019 Jan Horak <jhorak@redhat.com> - 71.0-17
- Fix for wrong intl.accept_lang when using non en-us langpack

* Mon Dec 9 2019 Martin Stransky <stransky@redhat.com> - 71.0-16
- Build with asan

* Mon Dec 9 2019 Martin Stransky <stransky@redhat.com> - 71.0-15
- Enabled Mozilla crash reporter
- Enabled PGO builds

* Mon Dec 9 2019 Martin Stransky <stransky@redhat.com> - 71.0-14
- Updated workaround for mzbz#1601707

* Sat Dec 7 2019 Martin Stransky <stransky@redhat.com> - 71.0-13
- Built with -fno-lifetime-dse

* Fri Dec 6 2019 Martin Stransky <stransky@redhat.com> - 71.0-12
- Clang test build, should fix extension breakage

* Fri Dec 6 2019 Martin Stransky <stransky@redhat.com> - 71.0-11
- Added workaround for:
  https://bugzilla.mozilla.org/show_bug.cgi?id=1601707
  http://gcc.gnu.org/PR92831

* Fri Dec 6 2019 Martin Stransky <stransky@redhat.com> - 71.0-10
- Remove appdata and ship metainfo only

* Wed Dec 4 2019 Martin Stransky <stransky@redhat.com> - 71.0-9
- Included kiosk mode workaround (mozbz#1594738)

* Tue Dec 3 2019 Martin Stransky <stransky@redhat.com> - 71.0-8
- Disabled PGO due to startup crash

* Mon Dec 2 2019 Martin Stransky <stransky@redhat.com> - 71.0-7
- Updated to 71.0 Build 5
- Updated Gnome search provider

* Wed Nov 27 2019 Martin Stransky <stransky@redhat.com> - 71.0-6
- Enable Gnome search provider

* Wed Nov 27 2019 Martin Stransky <stransky@redhat.com> - 71.0-5
- Added fix for mozbz#1593408
- Temporary disable Gnome search provider

* Tue Nov 26 2019 Martin Stransky <stransky@redhat.com> - 71.0-2
- Enable Gnome search provider

* Tue Nov 26 2019 Martin Stransky <stransky@redhat.com> - 71.0-1
- Updated to 71.0 Build 2

* Tue Nov 19 2019 Jan Horak <jhorak@redhat.com> - 70.0.1-5
- Added fixes for missing popup and overflow widget glitches

* Mon Nov 04 2019 Jan Horak <jhorak@redhat.com> - 70.0.1-4
- Added fix for non-scrollable popups

* Fri Nov 1 2019 Martin Stransky <stransky@redhat.com> - 70.0.1-1
- Updated to 70.0.1
- Built with system-nss (reverted 70.0-2 change).

* Thu Oct 31 2019 Martin Stransky <stransky@redhat.com> - 70.0-2
- Switched to in-tree nss due to rhbz#1752303

* Tue Oct 15 2019 Martin Stransky <stransky@redhat.com> - 70.0-1
- Updated to 70.0
